@@ -1,13 +1,10 @@
-"""
-    Slixmpp: The Slick XMPP Library
-    Copyright (C) 2010  Nathanael C. Fritz
-    This file is part of Slixmpp.
 
-    See the file LICENSE for copying permission.
-"""
-
-from collections import OrderedDict
-from slixmpp.xmlstream import StanzaBase
+# Slixmpp: The Slick XMPP Library
+# Copyright (C) 2010  Nathanael C. Fritz
+# This file is part of Slixmpp.
+# See the file LICENSE for copying permission.
+from slixmpp.xmlstream import StanzaBase, ElementBase
+from typing import ClassVar, Dict, Type
 
 
 class StreamFeatures(StanzaBase):
@@ -17,10 +14,10 @@ class StreamFeatures(StanzaBase):
 
     name = 'features'
     namespace = 'http://etherx.jabber.org/streams'
-    interfaces = set(('features', 'required', 'optional'))
+    interfaces = {'features', 'required', 'optional'}
     sub_interfaces = interfaces
-    plugin_tag_map = {}
-    plugin_attrib_map = {}
+    plugin_attrib_map: ClassVar[Dict[str, Type[ElementBase]]] = {}
+    plugin_tag_map: ClassVar[Dict[str, Type[ElementBase]]] = {}
 
     def setup(self, xml):
         StanzaBase.setup(self, xml)
@@ -29,7 +26,7 @@ class StreamFeatures(StanzaBase):
     def get_features(self):
         """
         """
-        features = OrderedDict()
+        features = {}
         for (name, lang), plugin in self.plugins.items():
             features[name] = plugin
         return features
