@@ -1,19 +1,22 @@
-"""
-    Slixmpp: The Slick XMPP Library
-    Copyright (C) 2012 Nathanael C. Fritz, Lance J.T. Stout
-    This file is part of Slixmpp.
-
-    See the file LICENSE for copying permission.
-"""
 
+# Slixmpp: The Slick XMPP Library
+# Copyright (C) 2012 Nathanael C. Fritz, Lance J.T. Stout
+# This file is part of Slixmpp.
+# See the file LICENSE for copying permission.
 import logging
+from asyncio import Future
 from datetime import datetime, timedelta
+from typing import (
+    Dict,
+    Optional
+)
 
-from slixmpp.plugins import BasePlugin, register_plugin
-from slixmpp import future_wrapper, Iq
+from slixmpp.plugins import BasePlugin
+from slixmpp import JID
+from slixmpp.stanza import Iq
 from slixmpp.exceptions import XMPPError
-from slixmpp.xmlstream import JID, register_stanza_plugin
-from slixmpp.xmlstream.handler import Callback
+from slixmpp.xmlstream import register_stanza_plugin
+from slixmpp.xmlstream.handler import CoroutineCallback
 from slixmpp.xmlstream.matcher import StanzaPath
 from slixmpp.plugins.xep_0012 import stanza, LastActivity
 
@@ -38,7 +41,7 @@ class XEP_0012(BasePlugin):
         self._last_activities = {}
 
         self.xmpp.register_handler(
-            Callback('Last Activity',
+            CoroutineCallback('Last Activity',
                  StanzaPath('iq@type=get/last_activity'),
                  self._handle_get_last_activity))
 
@@ -59,26 +62,56 @@ class XEP_0012(BasePlugin):
     def session_bind(self, jid):
         self.xmpp['xep_0030'].add_feature('jabber:iq:last')
 
-    def begin_idle(self, jid=None, status=None):
-        self.set_last_activity(jid, 0, status)
+    def begin_idle(self, jid: Optional[JID] = None, status: Optional[str] = None) -> Future:
+        """Reset the last activity for the given JID.
 
-    def end_idle(self, jid=None):
-        self.del_last_activity(jid)
+        .. versionchanged:: 1.8.0
+            This function now returns a Future.
 
-    def start_uptime(self, status=None):
-        self.set_last_activity(None, 0, status)
+        :param status: Optional status.
+        """
+        return self.set_last_activity(jid, 0, status)
 
-    def set_last_activity(self, jid=None, seconds=None, status=None):
-        self.api['set_last_activity'](jid, args={
+    def end_idle(self, jid: Optional[JID] = None) -> Future:
+        """Remove the last activity of a JID.
+
+        .. versionchanged:: 1.8.0
+            This function now returns a Future.
+        """
+        return self.del_last_activity(jid)
+
+    def start_uptime(self, status: Optional[str] = None) -> Future:
+        """
+        .. versionchanged:: 1.8.0
+            This function now returns a Future.
+        """
+        return self.set_last_activity(None, 0, status)
+
+    def set_last_activity(self, jid=None, seconds=None, status=None) -> Future:
+        """Set last activity for a JID.
+
+        .. versionchanged:: 1.8.0
+            This function now returns a Future.
+        """
+        return self.api['set_last_activity'](jid, args={
             'seconds': seconds,
-            'status': status})
+            'status': status
+        })
 
-    def del_last_activity(self, jid):
-        self.api['del_last_activity'](jid)
+    def del_last_activity(self, jid: JID) -> Future:
+        """Remove the last activity of a JID.
 
-    @future_wrapper
-    def get_last_activity(self, jid, local=False, ifrom=None, timeout=None,
-                          callback=None, timeout_callback=None):
+        .. versionchanged:: 1.8.0
+            This function now returns a Future.
+        """
+        return self.api['del_last_activity'](jid)
+
+    def get_last_activity(self, jid: JID, local: bool = False,
+                          ifrom: Optional[JID] = None, **iqkwargs) -> Future:
+        """Get last activity for a specific JID.
+
+        :param local: Fetch the value from the local cache.
+        """
         if jid is not None and not isinstance(jid, JID):
             jid = JID(jid)
 
@@ -94,25 +127,21 @@ class XEP_0012(BasePlugin):
             log.debug("Looking up local last activity data for %s", jid)
             return self.api['get_last_activity'](jid, None, ifrom, None)
 
-        iq = self.xmpp.Iq()
-        iq['from'] = ifrom
-        iq['to'] = jid
-        iq['type'] = 'get'
+        iq = self.xmpp.make_iq_get(ito=jid, ifrom=ifrom)
         iq.enable('last_activity')
-        return iq.send(timeout=timeout, callback=callback,
-                       timeout_callback=timeout_callback)
+        return iq.send(**iqkwargs)
 
-    def _handle_get_last_activity(self, iq):
+    async def _handle_get_last_activity(self, iq: Iq):
         log.debug("Received last activity query from " + \
                   "<%s> to <%s>.", iq['from'], iq['to'])
-        reply = self.api['get_last_activity'](iq['to'], None, iq['from'], iq)
+        reply = await self.api['get_last_activity'](iq['to'], None, iq['from'], iq)
         reply.send()
 
     # =================================================================
     # Default in-memory implementations for storing last activity data.
     # =================================================================
 
-    def _default_set_last_activity(self, jid, node, ifrom, data):
+    def _default_set_last_activity(self, jid: JID, node: str, ifrom: JID, data: Dict):
         seconds = data.get('seconds', None)
         if seconds is None:
             seconds = 0
@@ -125,11 +154,11 @@ class XEP_0012(BasePlugin):
             'seconds': datetime.now() - timedelta(seconds=seconds),
             'status': status}
 
-    def _default_del_last_activity(self, jid, node, ifrom, data):
+    def _default_del_last_activity(self, jid: JID, node: str, ifrom: JID, data: Dict):
         if jid in self._last_activities:
             del self._last_activities[jid]
 
-    def _default_get_last_activity(self, jid, node, ifrom, iq):
+    def _default_get_last_activity(self, jid: JID, node: str, ifrom: JID, iq: Iq) -> Iq:
         if not isinstance(iq, Iq):
             reply = self.xmpp.Iq()
         else:
