@@ -1,11 +1,8 @@
-"""
-    Slixmpp: The Slick XMPP Library
-    Copyright (C) 2013 Nathanael C. Fritz, Lance J.T. Stout
-    This file is part of Slixmpp.
-
-    See the file LICENSE for copying permission.
-"""
 
+# Slixmpp: The Slick XMPP Library
+# Copyright (C) 2013 Nathanael C. Fritz, Lance J.T. Stout
+# This file is part of Slixmpp.
+# See the file LICENSE for copying permission.
 from slixmpp.xmlstream import ElementBase, register_stanza_plugin
 
 
@@ -21,9 +18,9 @@ class Address(ElementBase):
     namespace = 'urn:xmpp:reach:0'
     plugin_attrib = 'address'
     plugin_multi_attrib = 'addresses'
-    interfaces = set(['uri', 'desc'])
-    lang_interfaces = set(['desc'])
-    sub_interfaces = set(['desc'])
+    interfaces = {'uri', 'desc'}
+    lang_interfaces = {'desc'}
+    sub_interfaces = {'desc'}
 
 
 register_stanza_plugin(Reachability, Address, iterable=True)
