@@ -1,11 +1,8 @@
-"""
-    Slixmpp: The Slick XMPP Library
-    Copyright (C) 2011  Nathanael C. Fritz
-    This file is part of Slixmpp.
-
-    See the file LICENSE for copying permission.
-"""
 
+# Slixmpp: The Slick XMPP Library
+# Copyright (C) 2011  Nathanael C. Fritz
+# This file is part of Slixmpp.
+# See the file LICENSE for copying permission.
 from slixmpp.xmlstream import ElementBase
 
 
@@ -16,6 +13,6 @@ class Bind(ElementBase):
 
     name = 'bind'
     namespace = 'urn:ietf:params:xml:ns:xmpp-bind'
-    interfaces = set(('resource', 'jid'))
+    interfaces = {'resource', 'jid'}
     sub_interfaces = interfaces
     plugin_attrib = 'bind'
