@@ -1,11 +1,7 @@
-"""
-    Slixmpp: The Slick XMPP Library
-    Copyright (C) 2011  Nathanael C. Fritz
-    This file is part of Slixmpp.
-
-    See the file LICENSE for copying permission.
-"""
-
+# Slixmpp: The Slick XMPP Library
+# Copyright (C) 2011  Nathanael C. Fritz
+# This file is part of Slixmpp.
+# See the file LICENSE for copying permission.
 import ssl
 import logging
 
@@ -18,6 +14,8 @@ from slixmpp.xmlstream.matcher import MatchXPath
 from slixmpp.xmlstream.handler import Callback
 from slixmpp.features.feature_mechanisms import stanza
 
+from typing import ClassVar, Set
+
 
 log = logging.getLogger(__name__)
 
@@ -26,7 +24,7 @@ class FeatureMechanisms(BasePlugin):
 
     name = 'feature_mechanisms'
     description = 'RFC 6120: Stream Feature: SASL'
-    dependencies = set()
+    dependencies: ClassVar[Set[str]] = set()
     stanza = stanza
     default_config = {
         'use_mech': None,
@@ -97,7 +95,10 @@ class FeatureMechanisms(BasePlugin):
                 jid = self.xmpp.requested_jid.bare
                 result[value] = creds.get('email', jid)
             elif value == 'channel_binding':
-                result[value] = self.xmpp.socket.get_channel_binding()
+                if isinstance(self.xmpp.socket, (ssl.SSLSocket, ssl.SSLObject)):
+                    result[value] = self.xmpp.socket.get_channel_binding()
+                else:
+                    result[value] = None
             elif value == 'host':
                 result[value] = creds.get('host', self.xmpp.requested_jid.domain)
             elif value == 'realm':
