@@ -1,11 +1,8 @@
-"""
-    Slixmpp: The Slick XMPP Library
-    Copyright (C) 2011  Nathanael C. Fritz
-    This file is part of Slixmpp.
-
-    See the file LICENSE for copying permission.
-"""
 
+# Slixmpp: The Slick XMPP Library
+# Copyright (C) 2011  Nathanael C. Fritz
+# This file is part of Slixmpp.
+# See the file LICENSE for copying permission.
 import base64
 
 from slixmpp.util import bytes
@@ -19,7 +16,7 @@ class Challenge(StanzaBase):
 
     name = 'challenge'
     namespace = 'urn:ietf:params:xml:ns:xmpp-sasl'
-    interfaces = set(('value',))
+    interfaces = {'value'}
     plugin_attrib = name
 
     def setup(self, xml):
