@@ -1,11 +1,8 @@
-"""
-    Slixmpp: The Slick XMPP Library
-    Copyright (C) 2011  Nathanael C. Fritz
-    This file is part of Slixmpp.
-
-    See the file LICENSE for copying permission.
-"""
 
+# Slixmpp: The Slick XMPP Library
+# Copyright (C) 2011  Nathanael C. Fritz
+# This file is part of Slixmpp.
+# See the file LICENSE for copying permission.
 import asyncio
 import logging
 
@@ -14,6 +11,7 @@ from slixmpp.xmlstream import register_stanza_plugin
 from slixmpp.plugins import BasePlugin
 
 from slixmpp.features.feature_session import stanza
+from typing import  ClassVar, Set
 
 
 log = logging.getLogger(__name__)
@@ -23,7 +21,7 @@ class FeatureSession(BasePlugin):
 
     name = 'feature_session'
     description = 'RFC 3920: Stream Feature: Start Session'
-    dependencies = set()
+    dependencies: ClassVar[Set[str]] = set()
     stanza = stanza
 
     def plugin_init(self):
@@ -35,18 +33,22 @@ class FeatureSession(BasePlugin):
         register_stanza_plugin(Iq, stanza.Session)
         register_stanza_plugin(StreamFeatures, stanza.Session)
 
-    @asyncio.coroutine
-    def _handle_start_session(self, features):
+    async def _handle_start_session(self, features):
         """
         Handle the start of the session.
 
         Arguments:
             feature -- The stream features element.
         """
+        if features['session']['optional']:
+            self.xmpp.sessionstarted = True
+            self.xmpp.event('session_start')
+            return
+
         iq = self.xmpp.Iq()
         iq['type'] = 'set'
         iq.enable('session')
-        yield from iq.send(callback=self._on_start_session_response)
+        await iq.send(callback=self._on_start_session_response)
 
     def _on_start_session_response(self, response):
         self.xmpp.features.add('session')
