@@ -1,22 +1,20 @@
-# -*- coding: utf-8 -*-
-"""
-    slixmpp.jid
-    ~~~~~~~~~~~~~~~~~~~~~~~
 
-    This module allows for working with Jabber IDs (JIDs).
-
-    Part of Slixmpp: The Slick XMPP Library
-
-    :copyright: (c) 2011 Nathanael C. Fritz
-    :license: MIT, see LICENSE for more details
-"""
+# slixmpp.jid
+# ~~~~~~~~~~~~~~~~~~~~~~~
+# This module allows for working with Jabber IDs (JIDs).
+# Part of Slixmpp: The Slick XMPP Library
+# :copyright: (c) 2011 Nathanael C. Fritz
+# :license: MIT, see LICENSE for more details
+from __future__ import annotations
 
 import re
 import socket
 
-from copy import deepcopy
 from functools import lru_cache
-from typing import Optional
+from typing import (
+    Optional,
+    Union,
+)
 
 from slixmpp.stringprep import nodeprep, resourceprep, idna, StringprepError
 
@@ -48,7 +46,7 @@ JID_UNESCAPE_TRANSFORMATIONS = {'\\20': ' ',
 
 # TODO: Find the best cache size for a standard usage.
 @lru_cache(maxsize=1024)
-def _parse_jid(data):
+def _parse_jid(data: str):
     """
     Parse string data into the node, domain, and resource
     components of a JID, if possible.
@@ -135,15 +133,15 @@ def _validate_domain(domain: str):
         try:
             domain = idna(domain)
         except StringprepError:
-            raise InvalidJID('idna validation failed')
+            raise InvalidJID(f'idna validation failed: {domain}')
 
         if ':' in domain:
-            raise InvalidJID('Domain containing a port')
+            raise InvalidJID(f'Domain containing a port: {domain}')
         for label in domain.split('.'):
             if not label:
-                raise InvalidJID('Domain containing too many dots')
+                raise InvalidJID(f'Domain containing too many dots: {domain}')
             if '-' in (label[0], label[-1]):
-                raise InvalidJID('Domain started or ended with -')
+                raise InvalidJID(f'Domain starting or ending with -: {domain}')
 
     if not domain:
         raise InvalidJID('Domain must not be 0 bytes')
@@ -311,7 +309,7 @@ class JID:
 
     __slots__ = ('_node', '_domain', '_resource', '_bare', '_full')
 
-    def __init__(self, jid: Optional[str] = None):
+    def __init__(self, jid: Optional[Union[str, 'JID']] = None):
         if not jid:
             self._node = ''
             self._domain = ''
@@ -353,35 +351,9 @@ class JID:
                       else self._bare)
 
     @property
-    def node(self):
-        return self._node
-
-    @property
-    def domain(self):
-        return self._domain
-
-    @property
-    def resource(self):
-        return self._resource
-
-    @property
-    def bare(self):
+    def bare(self) -> str:
         return self._bare
 
-    @property
-    def full(self):
-        return self._full
-
-    @node.setter
-    def node(self, value: str):
-        self._node = _validate_node(value)
-        self._update_bare_full()
-
-    @domain.setter
-    def domain(self, value: str):
-        self._domain = _validate_domain(value)
-        self._update_bare_full()
-
     @bare.setter
     def bare(self, value: str):
         node, domain, resource = _parse_jid(value)
@@ -390,11 +362,38 @@ class JID:
         self._domain = domain
         self._update_bare_full()
 
+
+    @property
+    def node(self) -> str:
+        return self._node
+
+    @node.setter
+    def node(self, value: Optional[str]):
+        self._node = _validate_node(value)
+        self._update_bare_full()
+
+    @property
+    def domain(self) -> str:
+        return self._domain
+
+    @domain.setter
+    def domain(self, value: str):
+        self._domain = _validate_domain(value)
+        self._update_bare_full()
+
+    @property
+    def resource(self) -> str:
+        return self._resource
+
     @resource.setter
-    def resource(self, value: str):
+    def resource(self, value: Optional[str]):
         self._resource = _validate_resource(value)
         self._update_bare_full()
 
+    @property
+    def full(self) -> str:
+        return self._full
+
     @full.setter
     def full(self, value: str):
         self._node, self._domain, self._resource = _parse_jid(value)
