@@ -1,11 +1,8 @@
-"""
-    Slixmpp: The Slick XMPP Library
-    Copyright (C) 2011  Nathanael C. Fritz
-    This file is part of Slixmpp.
-
-    See the file LICENSE for copying permission.
-"""
 
+# Slixmpp: The Slick XMPP Library
+# Copyright (C) 2011  Nathanael C. Fritz
+# This file is part of Slixmpp.
+# See the file LICENSE for copying permission.
 from slixmpp import Iq, Message
 from slixmpp.xmlstream import register_stanza_plugin, ElementBase, ET, JID
 from slixmpp.plugins import xep_0004
@@ -82,9 +79,9 @@ class Item(ElementBase):
             self.xml.append(value)
 
     def get_payload(self):
-        childs = list(self.xml)
-        if len(childs) > 0:
-            return childs[0]
+        children = list(self.xml)
+        if len(children) > 0:
+            return children[0]
 
     def del_payload(self):
         for child in self.xml:
