@@ -1,11 +1,8 @@
-"""
-    Slixmpp: The Slick XMPP Library
-    Copyright (C) 2011 Nathanael C. Fritz, Lance J.T. Stout
-    This file is part of Slixmpp.
-
-    See the file LICENSE for copying permission.
-"""
 
+# Slixmpp: The Slick XMPP Library
+# Copyright (C) 2011 Nathanael C. Fritz, Lance J.T. Stout
+# This file is part of Slixmpp.
+# See the file LICENSE for copying permission.
 from slixmpp.xmlstream import ElementBase
 
 
@@ -17,8 +14,8 @@ class OOBTransfer(ElementBase):
     name = 'query'
     namespace = 'jabber:iq:oob'
     plugin_attrib = 'oob_transfer'
-    interfaces = set(('url', 'desc', 'sid'))
-    sub_interfaces = set(('url', 'desc'))
+    interfaces = {'url', 'desc', 'sid'}
+    sub_interfaces = {'url', 'desc'}
 
 
 class OOB(ElementBase):
@@ -29,5 +26,5 @@ class OOB(ElementBase):
     name = 'x'
     namespace = 'jabber:x:oob'
     plugin_attrib = 'oob'
-    interfaces = set(('url', 'desc'))
+    interfaces = {'url', 'desc'}
     sub_interfaces = interfaces
