@@ -1,11 +1,8 @@
-"""
-    Slixmpp: The Slick XMPP Library
-    Copyright (C) 2012 Nathanael C. Fritz, Lance J.T. Stout
-    This file is part of Slixmpp.
-
-    See the file LICENSE for copying permission.
-"""
 
+# Slixmpp: The Slick XMPP Library
+# Copyright (C) 2012 Nathanael C. Fritz, Lance J.T. Stout
+# This file is part of Slixmpp.
+# See the file LICENSE for copying permission.
 from slixmpp.xmlstream import ET, ElementBase, JID
 
 
@@ -13,7 +10,7 @@ class BlockList(ElementBase):
     name = 'blocklist'
     namespace = 'urn:xmpp:blocking'
     plugin_attrib = 'blocklist'
-    interfaces = set(['items'])
+    interfaces = {'items'}
 
     def get_items(self):
         result = set()
