@@ -1,11 +1,8 @@
-"""
-    Slixmpp: The Slick XMPP Library
-    Copyright (C) 2012 Nathanael C. Fritz, Lance J.T. Stout
-    This file is part of Slixmpp.
-
-    See the file LICENSE for copying permission.
-"""
 
+# Slixmpp: The Slick XMPP Library
+# Copyright (C) 2012 Nathanael C. Fritz, Lance J.T. Stout
+# This file is part of Slixmpp.
+# See the file LICENSE for copying permission.
 import logging
 
 from slixmpp.plugins import BasePlugin
@@ -21,7 +18,7 @@ class XEP_0221(BasePlugin):
 
     name = 'xep_0221'
     description = 'XEP-0221: Data Forms Media Element'
-    dependencies = set(['xep_0004'])
+    dependencies = {'xep_0004'}
 
     def plugin_init(self):
         register_stanza_plugin(FormField, Media)
