@@ -1,17 +1,14 @@
-"""
-    Slixmpp: The Slick XMPP Library
-    Implementation of xeps for Internet of Things
-    http://wiki.xmpp.org/web/Tech_pages/IoT_systems
-    Copyright (C) 2013 Sustainable Innovation, Joachim.lindborg@sust.se, bjorn.westrom@consoden.se
-    This file is part of Slixmpp.
-
-    See the file LICENSE for copying permission.
-"""
 
+# Slixmpp: The Slick XMPP Library
+# Implementation of xeps for Internet of Things
+# http://wiki.xmpp.org/web/Tech_pages/IoT_systems
+# Copyright (C) 2013 Sustainable Innovation, Joachim.lindborg@sust.se, bjorn.westrom@consoden.se
+# This file is part of Slixmpp.
+# See the file LICENSE for copying permission.
+import asyncio
 import logging
 import time
 
-from slixmpp import asyncio
 from functools import partial
 from slixmpp.xmlstream import JID
 from slixmpp.xmlstream.handler import Callback
