@@ -1,11 +1,8 @@
-"""
-    Slixmpp: The Slick XMPP Library
-    Copyright (C) 2010  Nathanael C. Fritz
-    This file is part of Slixmpp.
-
-    See the file LICENSE for copying permission.
-"""
 
+# Slixmpp: The Slick XMPP Library
+# Copyright (C) 2010  Nathanael C. Fritz
+# This file is part of Slixmpp.
+# See the file LICENSE for copying permission.
 from slixmpp.xmlstream import ElementBase, register_stanza_plugin
 
 class AtomEntry(ElementBase):
@@ -21,9 +18,8 @@ class AtomEntry(ElementBase):
     namespace = 'http://www.w3.org/2005/Atom'
     name = 'entry'
     plugin_attrib = 'entry'
-    interfaces = set(('title', 'summary', 'id', 'published', 'updated'))
-    sub_interfaces = set(('title', 'summary', 'id', 'published',
-                          'updated'))
+    interfaces = {'title', 'summary', 'id', 'published', 'updated'}
+    sub_interfaces = {'title', 'summary', 'id', 'published', 'updated'}
 
 class AtomAuthor(ElementBase):
 
@@ -37,7 +33,7 @@ class AtomAuthor(ElementBase):
 
     name = 'author'
     plugin_attrib = 'author'
-    interfaces = set(('name', 'uri'))
-    sub_interfaces = set(('name', 'uri'))
+    interfaces = {'name', 'uri'}
+    sub_interfaces = {'name', 'uri'}
 
 register_stanza_plugin(AtomEntry, AtomAuthor)
