@@ -1,15 +1,12 @@
-"""
-    Slixmpp: The Slick XMPP Library
-    Copyright (C) 2010  Nathanael C. Fritz
-    This file is part of Slixmpp.
-
-    See the file LICENSE for copying permission.
-"""
 
+# Slixmpp: The Slick XMPP Library
+# Copyright (C) 2010  Nathanael C. Fritz
+# This file is part of Slixmpp.
+# See the file LICENSE for copying permission.
+import asyncio
 from slixmpp.stanza.rootstanza import RootStanza
 from slixmpp.xmlstream import StanzaBase, ET
-from slixmpp.xmlstream.handler import Waiter, Callback, CoroutineCallback
-from slixmpp.xmlstream.asyncio import asyncio
+from slixmpp.xmlstream.handler import Callback, CoroutineCallback
 from slixmpp.xmlstream.matcher import MatchIDSender, MatcherId
 from slixmpp.exceptions import IqTimeout, IqError
 
@@ -61,14 +58,14 @@ class Iq(RootStanza):
     types = {'get', 'result', 'set', 'error'}
     plugin_attrib = name
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, *args, recv=False, **kwargs):
         """
         Initialize a new <iq> stanza with an 'id' value.
 
         Overrides StanzaBase.__init__.
         """
         StanzaBase.__init__(self, *args, **kwargs)
-        if self['id'] == '':
+        if not recv and self['id'] == '':
             if self.stream is not None:
                 self['id'] = self.stream.new_id()
             else:
@@ -187,12 +184,18 @@ class Iq(RootStanza):
 
         future = asyncio.Future()
 
+        # Prevents handlers from existing forever.
+        if timeout is None:
+            timeout = 120
+
         def callback_success(result):
             type_ = result['type']
             if type_ == 'result':
-                future.set_result(result)
+                if not future.done():
+                    future.set_result(result)
             elif type_ == 'error':
-                future.set_exception(IqError(result))
+                if not future.done():
+                    future.set_exception(IqError(result))
             else:
                 # Most likely an iq addressed to ourself, rearm the callback.
                 handler = constr(handler_name,
@@ -208,7 +211,8 @@ class Iq(RootStanza):
                 callback(result)
 
         def callback_timeout():
-            future.set_exception(IqTimeout(self))
+            if not future.done():
+                future.set_exception(IqTimeout(self))
             self.stream.remove_handler('IqCallback_%s' % self['id'])
             if timeout_callback is not None:
                 timeout_callback(self)
