@@ -1,12 +1,10 @@
-"""
-    Slixmpp: The Slick XMPP Library
-    Copyright (C) 2010  Nathanael C. Fritz
-    This file is part of Slixmpp.
-
-    See the file LICENSE for copying permission.
-"""
 
+# Slixmpp: The Slick XMPP Library
+# Copyright (C) 2010  Nathanael C. Fritz
+# This file is part of Slixmpp.
+# See the file LICENSE for copying permission.
 from slixmpp.xmlstream.handler import Callback
+from slixmpp.xmlstream.stanzabase import StanzaBase
 
 
 class XMLCallback(Callback):
@@ -20,7 +18,7 @@ class XMLCallback(Callback):
         run -- Overrides Callback.run
     """
 
-    def run(self, payload, instream=False):
+    def run(self, payload: StanzaBase, instream: bool = False) -> None:
         """
         Execute the callback function with the matched stanza's
         XML contents, instead of the stanza itself.
@@ -33,4 +31,4 @@ class XMLCallback(Callback):
                         stream processing. Used only by prerun.
                         Defaults to False.
         """
-        Callback.run(self, payload.xml, instream)
+        Callback.run(self, payload.xml, instream)  # type: ignore
