@@ -299,8 +299,8 @@ class XMLStream(asyncio.BaseProtocol):
         self.scheduled_events = {}
 
         self.ssl_context = ssl.create_default_context()
-        self.ssl_context.check_hostname = False
-        self.ssl_context.verify_mode = ssl.CERT_NONE
+        self.ssl_context.check_hostname = True
+        self.ssl_context.verify_mode = ssl.CERT_REQUIRED
 
         self.event_when_connected = "connected"
 
@@ -484,25 +484,21 @@ class XMLStream(asyncio.BaseProtocol):
         if self._current_connection_attempt is None:
             return
         try:
+            server_hostname = self.default_domain if self.use_ssl else None
             await self.loop.create_connection(lambda: self,
                                                    self.address[0],
                                                    self.address[1],
                                                    ssl=ssl_context,
-                                                   server_hostname=self.default_domain if self.use_ssl else None)
+                                                   server_hostname=server_hostname)
             self._connect_loop_wait = 0
         except Socket.gaierror as e:
             self.event('connection_failed',
                        'No DNS record available for %s' % self.default_domain)
+            self.reschedule_connection_attempt()
         except OSError as e:
             log.debug('Connection failed: %s', e)
             self.event("connection_failed", e)
-            if self._current_connection_attempt is None:
-                return
-            self._connect_loop_wait = self._connect_loop_wait * 2 + 1
-            self._current_connection_attempt = asyncio.ensure_future(
-                self._connect_routine(),
-                loop=self.loop,
-            )
+            self.reschedule_connection_attempt()
 
     def process(self, *, forever: bool = True, timeout: Optional[int] = None) -> None:
         """Process all the available XMPP events (receiving or sending data on the
@@ -579,7 +575,7 @@ class XMLStream(asyncio.BaseProtocol):
                                                        stream=self,
                                                        top_level=True,
                                                        open_only=True))
-                        self.start_stream_handler(self.xml_root)
+                        self.start_stream_handler(self.xml_root)  # type:ignore
                     self.xml_depth += 1
                 if event == 'end':
                     self.xml_depth -= 1
@@ -638,6 +634,20 @@ class XMLStream(asyncio.BaseProtocol):
         self._set_disconnected_future()
         self.event("disconnected", self.disconnect_reason or exception)
 
+    def reschedule_connection_attempt(self) -> None:
+        """
+        Increase the exponential back-off and initate another background
+        _connect_routine call to connect to the server.
+        """
+        # abort if there is no ongoing connection attempt
+        if self._current_connection_attempt is None:
+            return
+        self._connect_loop_wait = min(300, self._connect_loop_wait * 2 + 1)
+        self._current_connection_attempt = asyncio.ensure_future(
+            self._connect_routine(),
+            loop=self.loop,
+        )
+
     def cancel_connection_attempt(self) -> None:
         """
         Immediately cancel the current create_connection() Future.
@@ -800,6 +810,8 @@ class XMLStream(asyncio.BaseProtocol):
 
             self.ssl_context.verify_mode = ssl.CERT_REQUIRED
             self.ssl_context.load_verify_locations(cafile=ca_cert)
+        else:
+            self.ssl_context.set_default_verify_paths()
 
         return self.ssl_context
 
@@ -816,15 +828,15 @@ class XMLStream(asyncio.BaseProtocol):
         try:
             if hasattr(self.loop, 'start_tls'):
                 transp = await self.loop.start_tls(self.transport,
-                                                   self, ssl_context)
+                                                   self, ssl_context,
+                                                   server_hostname=self.default_domain)
             # Python < 3.7
             else:
                 transp, _ = await self.loop.create_connection(
                     lambda: self,
                     ssl=self.ssl_context,
                     sock=self.socket,
-                    server_hostname=self.default_domain
-                )
+                    server_hostname=self.default_domain)
         except ssl.SSLError as e:
             log.debug('SSL: Unable to connect', exc_info=True)
             log.error('CERT: Invalid certificate trust chain.')
@@ -1256,7 +1268,7 @@ class XMLStream(asyncio.BaseProtocol):
                             already_run_filters.add(filter)
                             if iscoroutinefunction(filter):
                                 filter = cast(AsyncFilter, filter)
-                                task = asyncio.create_task(filter(data))
+                                task = asyncio.create_task(filter(data))  # type:ignore
                                 completed, pending = await wait(
                                     {task},
                                     timeout=1,
